#!/usr/bin/env python3

from pathlib import Path

from .sat import SATPortal
from .cfdi_cert import CertSign
from settings import log

from time import sleep

def is_dir(path):
    return Path(path).is_dir()


def join(*paths):
    return Path(paths[0]).joinpath(*paths[1:])


def _validate_fiel_args(args):
    fiel_path = args.fiel_directorio
    fiel_name = args.fiel_nombre

    if not fiel_path:
        msg = 'El directorio con la FIEL es requerido'
        log.error(msg)
        return False, {}

    if not is_dir(fiel_path):
        msg = f'La ruta no existe o no es un directorio. \nRuta: {fiel_path}'
        log.error(msg)
        return False, {}

    path_cer = join(fiel_path, f'{fiel_name}.cer')
    path_key = join(fiel_path, f'{fiel_name}.key')
    path_enc = join(fiel_path, f'{fiel_name}.enc')
    path_pem = join(fiel_path, f'{fiel_name}.pem')

    if not path_cer.is_file():
        msg = f'No se encontró el archivo CER. \nRuta: {path_cer}'
        log.error(msg)
        return False, {}

    if not path_key.is_file():
        msg = f'No se encontró el archivo KEY. \nRuta: {path_key}'
        log.error(msg)
        return False, {}

    data = {
        'cer': path_cer.read_bytes(),
        'key': path_key.read_bytes(),
        # ~ 'enc': path_enc.read_bytes(),
        'pem': path_pem.read_bytes(),
    }
    return True, data


def download_web(args):
    # ~ print(args)
    result, files = _validate_fiel_args(args)
    if not result:
        return

    fiel = CertSign(files['pem'])
    fiel.get_data_cer(files['cer'])

    sat = SATPortal()
    if sat.login(fiel):
        sleep(3)
        sat.logout()

    return
